# GraphQL Compose: Webform

**Description**:
The `graphql_compose_webform` module integrates Drupal Webform with GraphQL Compose, allowing webform data to be exposed and manipulated via GraphQL queries and mutations.

## Requirements

This module requires the following modules:
- [Webform](https://www.drupal.org/project/webform)
- [GraphQL Compose](https://www.drupal.org/project/graphql_compose)

## Installation

1. Install the required modules:
   ```sh
   composer require drupal/webform drupal/graphql_compose
   ```
2. Enable the module:
   ```
   drush en graphql_compose_webform
   ```

## Configuration
In the Graphql Compose settings you should be able to enable all the webform you created with the webform module.

When webforms are referenced in a paragraph, you should see the webform paragraph type in the settings and you should be able to enable the paragraph with an webform field.

## Usage
**Querying Webform Data**

You can query webform data using GraphQL. For example, to get the details of a webform:

```graphql
  query {
    webform(id: "contact") {
      id
      label
      description
      elements {
        key
        label
        type
        options {
          id
          value
        }
        states {
          type
          identifier
          active_on_value
        }
      }
    }
  }
```

**Submitting a Webform**

You can submit a webform using a GraphQL mutation. For example:

where the key is the id of the webform field.

```graphql
mutation {
  submitWebform(id: "contact", data: [
    {
      key: "name",
      value: "John Doe"
    },
    {
      key: "email",
      value: "john.doe@example.com"
    },
    {
      key: "message",
      value: "Hello!"
    }
  ]) {
    id
    label
    description
  }
}
```

## Maintainers
[Jeroen Schipper](https://www.drupal.org/u/jeroen_schipper), [DICTU](https://www.drupal.org/dictu)
